@@ -13,6 +13,8 @@
 ##############################################################################
 """Test Interface implementation
 """
+from __future__ import with_statement
+
 import doctest
 import unittest
 import sys
@@ -404,13 +406,18 @@ class InterfaceTests(unittest.TestCase):
                          hash((('IFoo', 'zope.interface.tests.ifoo'))))
 
     def test_hash_missing_required_attrs(self):
-        from warnings import catch_warnings
+        import warnings
+        try:
+            from warnings import catch_warnings
+        except ImportError:  # Python 2.5
+            return
         from zope.interface.interface import InterfaceClass
         class Derived(InterfaceClass):
             def __init__(self):
                 pass # Don't call base class.
         derived = Derived()
         with catch_warnings(record=True) as warned:
+            warnings.simplefilter('always') # see LP #825249 
             self.assertEqual(hash(derived), 1)
             self.assertEqual(len(warned), 1)
             self.failUnless(warned[0].category is UserWarning)
